timeintervaltools.round_interval_bounds_to_nearest_multiple_of_rational
=======================================================================

.. autofunction:: abjad.tools.timeintervaltools.round_interval_bounds_to_nearest_multiple_of_rational.round_interval_bounds_to_nearest_multiple_of_rational
